@@ -110,7 +110,7 @@
   "\n<!-- This file was autogenerated by Leiningen.
   Please do not edit it directly; instead edit project.clj and regenerate it.
   It should not be considered canonical data. For more information see
-  https://github.com/technomancy/leiningen -->\n")
+  https://codeberg.org/leiningen/leiningen -->\n")
 
 (defn- camelize [string]
   (s/replace string #"[-_](\w)" (comp s/upper-case second)))
@@ -415,15 +415,6 @@
           (xml-tags :project (relativize project))))
         (if disclaimer? disclaimer)))))
 
-(def ^:private warning
-  (delay
-   (main/warn "WARNNG: leiningen.pom/make-pom-properties is deprecated."
-              "\nUse leiningen.core.project/make-project-properties instead.")))
-
-(defn ^:deprecated make-pom-properties [project]
-  (force warning)
-  (project/make-project-properties))
-
 (defn ^{:help-arglists '([])} pom
   "Write a pom.xml file to disk for Maven interoperability."
   ([project pom-location-or-properties]
